<?php
/**
 * The create ONLINEmaps settings page.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\Admin\SettingsPage\OnlineMaps;

use Locr\WordPress\Plugin\LocrMaps\Admin\SettingsPage\OnlineMaps;
use Locr\WordPress\Plugin\LocrMaps\DDD\Entities\OnlineMap;
use Locr\WordPress\Plugin\LocrMaps\DDD\Repositories\OnlineMaps as OnlineMapsRepository;
use Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\OnlineMap\Id as OnlineMapId;
use Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\SettingsMessageId;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for rendering the main online maps settings page.
 */
final class Create {
	public const NONCE_ACTION = 'create_onlinemap';

	/**
	 * This function renders the main online maps settings page.
	 */
	public static function process(): never {
		$admin_url = admin_url( 'admin.php' );

		$wp_nonce = (string) ( filter_input( INPUT_GET, '_wpnonce', FILTER_DEFAULT ) ?? '' );
		if ( ! wp_verify_nonce( $wp_nonce, self::NONCE_ACTION ) ) {
			$invalid_nonce_admin_url_args = array(
				'page'    => OnlineMaps::SUB_PAGE_NAME,
				'message' => SettingsMessageId::InvalidNonce->value,
			);
			wp_safe_redirect( add_query_arg( $invalid_nonce_admin_url_args, $admin_url ) );
			exit;
		}

		$onlinemaps_repository = new OnlineMapsRepository();
		$onlinemap             = new OnlineMap( id: new OnlineMapId( PHP_INT_MAX ) );
		$onlinemaps_repository->add( $onlinemap );

		$admin_url = admin_url( 'admin.php' );
		$edit_args = array(
			'page'     => OnlineMaps::SUB_PAGE_NAME,
			'action'   => 'edit',
			'id'       => $onlinemap->id->value,
			'_wpnonce' => wp_create_nonce( Edit::NONCE_ACTION ),
		);
		wp_safe_redirect( add_query_arg( $edit_args, $admin_url ) );
		exit;
	}
}
